/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editpart.figure;

import java.util.Collection;

import org.eclipse.draw2d.Label;
import org.eclipse.draw2d.PositionConstants;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.PlatformUI;
import org.fortiss.tooling.kernel.extension.data.IConstraintViolation;

/**
 * Figure used for displaying decorator figures.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 941368BC6513E660CDC25E44EB53F349
 */
public class DecoratorFigure extends Label {

	/** Constructor. */
	public DecoratorFigure() {
		setTextAlignment(PositionConstants.LEFT | PositionConstants.TOP);
	}

	/** Updates the figure based on constraint violations. */
	public void setConstraintViolations(Collection<IConstraintViolation<EObject>> violations) {
		if(violations.isEmpty()) {
			setVisible(false);
			return;
		}

		setVisible(true);
		IConstraintViolation<EObject> highest = violations.iterator().next();

		switch(highest.getSeverity()) {
			case FATAL:
			case ERROR:
				setIcon(PlatformUI.getWorkbench().getSharedImages()
						.getImage(ISharedImages.IMG_OBJS_ERROR_TSK));
				break;
			case WARNING:
				setIcon(PlatformUI.getWorkbench().getSharedImages()
						.getImage(ISharedImages.IMG_OBJS_WARN_TSK));
				break;
			case INFO:
				setIcon(PlatformUI.getWorkbench().getSharedImages()
						.getImage(ISharedImages.IMG_OBJS_INFO_TSK));
				break;
		}

		setToolTip(new Label(highest.getExplanation()));
	}
}
