/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2012 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.graphicsGL.ui.objects;

import static org.fortiss.tooling.graphicsGL.ui.util.GLPrimitives.restoreMatrix;
import static org.fortiss.tooling.graphicsGL.ui.util.GLPrimitives.saveMatrix;
import static org.fortiss.tooling.graphicsGL.ui.util.GLPrimitives.scale;

import org.lwjglx.util.vector.Vector3f;

/**
 * Scales the wrapped object by the given factor.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 0812240BBBB798E6A0D0E47BFDC19A50
 */
public class ScaledObject extends WrappedViewObjectBase {
	/** The scale factor. */
	private Vector3f scaleFactor;

	/** Constructor. */
	public ScaledObject(ViewObjectBase wrapped, Vector3f factor) {
		super(wrapped);
		this.scaleFactor = factor;
	}

	/** {@inheritDoc} */
	@Override
	protected void preRendering() {
		saveMatrix();
		scale(scaleFactor);
	}

	/** {@inheritDoc} */
	@Override
	protected void postRendering() {
		restoreMatrix();
	}
}
