/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.actions;

import static org.fortiss.tooling.kernel.ui.internal.actions.CopyAction.doCopy;
import static org.fortiss.tooling.kernel.ui.internal.actions.DeleteAction.doDelete;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.actions.ActionFactory;
import org.fortiss.tooling.kernel.service.ICommandStackService;
import org.fortiss.tooling.kernel.service.IElementCompositorService;
import org.fortiss.tooling.kernel.ui.extension.base.EObjectActionBase;

/**
 * Action for cutting the current selection.
 * 
 * @author hummel
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 33F55671C69E93215F6695A8616CDE27
 */
public class CutAction extends EObjectActionBase<EObject> {

	/** Constructor. */
	public CutAction() {
		super("Cut", PlatformUI.getWorkbench().getSharedImages()
				.getImageDescriptor(ISharedImages.IMG_TOOL_CUT));
		setId(ActionFactory.CUT.getId());
	}

	/** {@inheritDoc} */
	@Override
	public void run() {
		ICommandStackService.getInstance().runAsCommand(getTarget(), new Runnable() {
			@Override
			public void run() {
				doCopy(getTargets());
				doDelete(getTargets());
			}
		});
	}

	/** {@inheritDoc} */
	@Override
	protected boolean computeEnabled() {
		return isGlobalCopyPasteActionsVisible() &&
				IElementCompositorService.getInstance().canDecompose(getTarget());
	}
}
