package org.fortiss.tooling.kernel.ui.service;

import java.util.Set;

import org.eclipse.jface.resource.ImageDescriptor;
import org.fortiss.tooling.kernel.model.constraints.Constraint;
import org.fortiss.tooling.kernel.model.constraints.IConstraintContainer;
import org.fortiss.tooling.kernel.model.constraints.IConstraintVerificationStatus;
import org.fortiss.tooling.kernel.service.IConstraintVerificationService;
import org.fortiss.tooling.kernel.ui.extension.IConstraintVerifierUI;
import org.fortiss.tooling.kernel.ui.internal.ConstraintVerificationUIService;

/**
 * GUI aspects of {@link IConstraintVerificationService}.
 * 
 * @author aravantinos
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: D385AA84897DCC95B76AA13E0A351ED2
 */
public interface IConstraintVerificationUIService {
	/** Returns the service instance. */
	public static IConstraintVerificationUIService getInstance() {
		return ConstraintVerificationUIService.getInstance();
	}

	/** Action to take when trying to open the (status of the given) constraint. */
	void openStatus(Constraint c);

	/** True if the (status of the) the given constraint can be open. */
	boolean canOpen(Constraint c);

	/** Install the given constraint: install notifiers and triggers an "onOutdate" event. */
	void install(Constraint constraint);

	/** Registers the verifier UI part with the kernel. */
	void registerConstraintVerifierUI(IConstraintVerifierUI verifier);

	/**
	 * True if a failure of the given constraint shall be displayed as a warning instead of an
	 * error.
	 */
	boolean shallDisplayAsWarning(Constraint constraint);

	/**
	 * The following features deal with the usage of constraints to drive the process.
	 * 
	 * EXPERIMENTAL.
	 */

	/**
	 * Returns the status of the constraint, possibly returns <code>null</code> if the constraint is
	 * not activated.
	 */
	IConstraintVerificationStatus getStatus(Constraint constraint);

	/** Returns a list of all available constraint types. */
	Set<String> getAvailableConstraintTypes();

	/** Activates the constraint type in the context of the given constraints container. */
	void activate(String id, IConstraintContainer cstrContainer);

	/** Deactivates the constraint type in the context of the given constraints container. */
	void deactivate(String id, IConstraintContainer cstrContainer);

	/** Returns a description for the given constraint type. */
	String getDescription(String id);

	/** Returns the image descriptor to be used as icon image. */
	ImageDescriptor getIconImageDescriptor(String id);
}
