/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2016 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.introspection.items;

import static java.util.Collections.unmodifiableList;

import java.util.List;

import org.fortiss.tooling.kernel.introspection.IIntrospectionDetailsItem;

/**
 * Base class for {@link IIntrospectionDetailsItem}s with a list of handlers.
 * <P>
 * The returned handler list is read-only.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: DED9C3436892C8CF2653700FA26A9429
 */
public abstract class HandlerListIntrospectionDetailsItemBase<T extends Object> implements
		IIntrospectionDetailsItem {

	/** Read-only copy of the services handler list. */
	protected final List<T> handlerList;

	/** Constructor. */
	public HandlerListIntrospectionDetailsItemBase(List<T> handlerList) {
		this.handlerList = handlerList;
	}

	/** Returns the handler list. */
	public List<T> getHandlerList() {
		return unmodifiableList(handlerList);
	}
}
