/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2013 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.utils;

import static org.fortiss.tooling.kernel.utils.EcoreUtils.getChildrenWithType;

import java.util.List;
import java.util.Map;

import org.eclipse.emf.common.util.BasicEList;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.emf.ecore.util.FeatureMap;
import org.eclipse.emf.ecore.xml.type.AnyType;

/**
 * Utility methods for the migrators.
 * 
 * @author SVoss
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating GREEN Hash: 3928E0887F8874121A2E37C5CB49246C
 */
public class MigrationUtils {

	/**
	 * Recursively delete all elements with a certain type from a certain scope.
	 * 
	 * @param parent
	 *            - the parent containing elements to be deleted
	 * @param clazz
	 *            - the class of the elements to be deleted
	 */
	@SuppressWarnings("unchecked")
	public static void deleteAllElementsWithType(EObject parent, Class<? extends EObject> clazz) {
		EList<EObject> elems = (EList<EObject>)(EList<?>)getChildrenWithType(parent, clazz);

		for(EObject obj : elems) {
			EcoreUtil.delete(obj);
		}
	}

	/** Extracts the list of feature names from a map of features. */
	public static List<String> featuresToStrings(Map<EObject, AnyType> features) {
		List<String> res = new BasicEList<String>();
		for(AnyType featuresPerKey : features.values()) {
			FeatureMap actualFeatures = featuresPerKey.getMixed();
			actualFeatures.addAll(featuresPerKey.getAnyAttribute());
			for(FeatureMap.Entry feature : actualFeatures) {
				res.add(feature.getEStructuralFeature().getName());
			}
		}
		return res;
	}
}
